#!/usr/bin/env node
/**
 * 批量处理指定目录中的所有小程序
 * 可递归遍历，自动识别，解压，转换源码
 */

const childProcess = require('child_process');
const fs = require('fs');
const path = require('path');
const Program = require('commander');

Program
  .description('批量转换工具')
  .parse(process.argv);

if (!Program.args.length) {
  Program.outputHelp();
  process.exit(0);
}
let counter = 0;
if (Program.args.length === 1) {
  const targetDir = path.resolve(Program.args[0]);
  // console.log(targetDir);
  transformer(targetDir);
  console.log(`总计转换小程序：${counter}个！`);
}

function transformer(target) {
  fs.readdirSync(target).forEach((dir, index) => {
    if (dir !== '.DS_Store') {
      // console.log(dir, index);
      let sourceDir = path.join(target, dir);
      if (validateAppSrc(sourceDir)) {
        executeTransform(sourceDir);
      } else if (dir.indexOf('(1).zip') !== -1) {
        console.warn(`'${sourceDir}'`);
        childProcess.execSync(`rm -rf "${sourceDir}"`);
      } else if (dir.endsWith('.zip') || dir.endsWith('.rar') || dir.endsWith('.gz')) {
        unzipFile(sourceDir);
      } else if (dir.indexOf('.') === -1 && !fs.statSync(sourceDir).isFile()) {
        transformer(sourceDir);
      }
    }
  });
}

function validateAppSrc(target) {
  const appJsFile = path.join(target, 'app.js');
  const appJsonFile = path.join(target, 'app.json');
  let ret = true;
  if (!fs.existsSync(appJsFile)) {
    ret = false;
  }
  if (!fs.existsSync(appJsonFile)) {
    ret = false;
  }
  return ret;
}

function unzipFile(target) {
  const parsedPath = path.parse(target);
  const newDirPath = path.join(parsedPath.dir, parsedPath.name);
  if (parsedPath.ext === '.zip') {
    console.log(target);
    childProcess.execSync(`7z x '${target}' -o${parsedPath.dir} -aoa `); // 覆盖解压
    // childProcess.execSync('7z x ' + target + ' -o' + parsedPath.dir); // 覆盖解压
    executeTransform(newDirPath);
  }
}

function executeTransform(target) {
  try {
    console.log(`~~~~开始转换小程序：${target}`);
    childProcess.execSync(`qa ${target} ${target + '-dist'}`);
    counter++;
    console.log(`~~~~转换完成：这是第${counter}个小程序！~~~~`);
  } catch (e) {
    console.warn(e);
  }
}
