"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const log_1 = require("../utils/log");
const tools_1 = require("../utils/tools");
const app_ux_1 = require("./transformers/app-ux");
const app_wxss_1 = require("./transformers/app-wxss");
const pages_1 = require("./transformers/pages");
const resource_1 = require("./transformers/resource");
const convert_app_json_1 = require("./transformers/manifest/convert-app-json");
const fs_1 = require("fs");
function validate(input) {
    const appJsFile = path_1.join(input, 'app.js');
    const appJsonFile = path_1.join(input, 'app.json');
    let ret = true;
    if (!fs_extra_1.existsSync(appJsFile)) {
        ret = false;
        log_1.error('缺少文件：' + appJsFile);
    }
    if (!fs_extra_1.existsSync(appJsonFile)) {
        ret = false;
        log_1.error('缺少文件：' + appJsonFile);
    }
    return ret;
}
exports.validate = validate;
exports.ignoreList = [];
function transformer(input, output, options) {
    fs_extra_1.emptyDirSync(output);
    const appJsonPath = path_1.join(input, 'app.json');
    const appJson = require(appJsonPath);
    const manifestJson = convert_app_json_1.convertAppJson(appJsonPath, { input });
    fs_extra_1.outputJSONSync(path_1.join(output, 'manifest.json'), manifestJson, { spaces: 2 });
    fs_extra_1.copySync(path_1.join(__dirname, '..', '..', 'static', 'polyfill'), path_1.join(output, 'polyfill'));
    const appJs = fs_extra_1.readFileSync(path_1.join(input, 'app.js'), 'utf-8');
    const appUx = app_ux_1.transformAppJs(appJs);
    fs_extra_1.outputFileSync(path_1.join(output, 'app.ux'), appUx);
    const appWxssPath = path_1.join(input, 'app.wxss');
    if (fs_extra_1.existsSync(appWxssPath)) {
        const appWxss = fs_extra_1.readFileSync(path_1.join(input, 'app.wxss'), 'utf-8');
        const appCss = app_wxss_1.transformAppWxss(appWxss);
        fs_extra_1.outputFileSync(path_1.join(output, 'app.css'), appCss);
    }
    exports.ignoreList.push(path_1.join(input, 'app.js'), path_1.join(input, 'app.json'), path_1.join(input, 'project.config.json'));
    appJson.pages.forEach((pagePath) => {
        let pageJsonData = null;
        if (fs_extra_1.existsSync(path_1.join(input, pagePath + '.json')) && !!fs_extra_1.readFileSync(path_1.join(input, pagePath + '.json'), 'utf-8')) {
            pageJsonData = require(path_1.join(input, pagePath + '.json'));
        }
        const pageOptions = {
            input,
            output,
            pagePath,
            pageJson: pageJsonData,
            tabBar: appJson.tabBar,
            entry: manifestJson.router.entry,
        };
        const filePaths = pagePath.split('/');
        filePaths.pop();
        const filePath = filePaths.join('/');
        const pageRelativePath = tools_1.relativePath(path_1.join(input, filePath), appWxssPath);
        const importCssPath = tools_1.normalizePath(pageRelativePath).replace('app.wxss', 'app.css');
        const importPolyfillCssPath = tools_1.normalizePath(pageRelativePath).replace('app.wxss', 'polyfill/stylesheet/polyfill.css');
        let importCode = `@import '${importPolyfillCssPath}';\r\n`;
        if (fs_extra_1.existsSync(appWxssPath)) {
            importCode += `@import '${importCssPath}';\r\n`;
        }
        const pageData = pages_1.transformPages(path_1.join(input, pagePath), importCode, pageOptions);
        const outputPath = tools_1.pop(pagePath.split('/')).join('/') + '/index.ux';
        const outPagePath = path_1.join(output, outputPath);
        fs_extra_1.outputFileSync(outPagePath, pageData);
    });
    if (!!appJson.subPackages || !!appJson.subpackages) {
        const subpackages = appJson.subPackages || appJson.subpackages;
        subpackages.forEach((pkg) => {
            pkg.pages.forEach((page) => {
                const pagePath = path_1.join(pkg.root, page);
                let pageJsonData = null;
                if (fs_extra_1.existsSync(path_1.join(input, pagePath + '.json')) && !!fs_extra_1.readFileSync(path_1.join(input, pagePath + '.json'), 'utf-8')) {
                    pageJsonData = require(path_1.join(input, pagePath + '.json'));
                }
                const pageOptions = {
                    input,
                    output,
                    pagePath,
                    pageJson: pageJsonData,
                    tabBar: appJson.tabBar,
                    entry: manifestJson.router.entry,
                };
                const filePaths = pagePath.split('/');
                filePaths.pop();
                const filePath = filePaths.join('/');
                const pageRelativePath = tools_1.relativePath(path_1.join(input, filePath), appWxssPath);
                const importCssPath = tools_1.normalizePath(pageRelativePath).replace('app.wxss', 'app.css');
                const importPolyfillCssPath = tools_1.normalizePath(pageRelativePath).replace('app.wxss', 'polyfill/stylesheet/polyfill.css');
                let importCode = `@import '${importPolyfillCssPath}';\r\n`;
                if (fs_extra_1.existsSync(appWxssPath)) {
                    importCode += `@import '${importCssPath}';\r\n`;
                }
                const pageData = pages_1.transformPages(path_1.join(input, pagePath), importCode, pageOptions);
                const outputPath = tools_1.pop(pagePath.split('/')).join('/') + '/index.ux';
                const outPagePath = path_1.join(output, outputPath);
                fs_extra_1.outputFileSync(outPagePath, pageData);
            });
        });
    }
    fs_1.readdirSync(input).forEach((file) => {
        const filePath = path_1.join(input, file);
        if (path_1.basename(filePath).toLowerCase() === 'common' && path_1.extname(filePath) === '') {
            fs_extra_1.copySync(filePath, path_1.join(output, file + '.bak'));
            exports.ignoreList.push(filePath);
        }
    });
    resource_1.transformResource(input, output, exports.ignoreList);
}
exports.transformer = transformer;
