"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs");
const path_1 = require("path");
function getBaseManifest() {
    return require(path.resolve(__dirname, './base.json'));
}
exports.getBaseManifest = getBaseManifest;
function getPageName(page) {
    const paths = page.split('/');
    paths.pop();
    return paths.join('/');
}
exports.getPageName = getPageName;
const windowKeysMap = {
    'navigationBarBackgroundColor': 'titleBarBackgroundColor',
    'navigationBarTextStyle': 'titleBarTextColor',
    'navigationBarTitleText': 'titleBarText',
    'backgroundColor': 'backgroundColor',
    'navigationStyle': 'titleBar',
};
function convertAppJson(appJsonPath, options) {
    const json = require(appJsonPath);
    const pages = json.pages;
    const routerPages = {};
    const displayPages = {};
    let entry = getPageName(pages[0]);
    pages.map(page => {
        const pageName = getPageName(page);
        if (page.startsWith('^')) {
            entry = pageName;
        }
        const routePage = {};
        routePage[pageName] = {
            component: 'index',
        };
        routerPages[pageName] = {
            component: 'index',
        };
        const displayPage = {};
        const pagePath = path.join(options.input, page + '.json');
        if (fs.existsSync(pagePath) && !!fs.readFileSync(pagePath, 'utf-8')) {
            const pageJson = require(pagePath);
            if (pageJson.navigationBarTitleText) {
                displayPage.titleBarText = pageJson.navigationBarTitleText;
            }
        }
        displayPages[pageName] = displayPage;
    });
    if (!!json.subPackages || !!json.subpackages) {
        const subpackages = json.subPackages || json.subpackages;
        subpackages.map((pkg) => {
            pkg.pages.map((item) => {
                const page = path_1.join(pkg.root, item);
                const pageName = getPageName(page);
                if (page.startsWith('^')) {
                    entry = pageName;
                }
                const routePage = {};
                routePage[pageName] = {
                    component: 'index',
                };
                routerPages[pageName] = {
                    component: 'index',
                };
                const displayPage = {};
                const pagePath = path.join(options.input, page + '.json');
                if (fs.existsSync(pagePath) && !!fs.readFileSync(pagePath, 'utf-8')) {
                    const pageJson = require(pagePath);
                    if (pageJson.navigationBarTitleText) {
                        displayPage.titleBarText = pageJson.navigationBarTitleText;
                    }
                }
                displayPages[pageName] = displayPage;
            });
        });
    }
    const outputManifest = getBaseManifest();
    const appJsWindow = json.window;
    Object.keys(appJsWindow).forEach((key) => {
        if (windowKeysMap[key]) {
            outputManifest.display[windowKeysMap[key]] = appJsWindow[key];
        }
    });
    outputManifest.router.entry = entry;
    outputManifest.router.pages = routerPages;
    outputManifest.display.pages = displayPages;
    return outputManifest;
}
exports.convertAppJson = convertAppJson;
