"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("fs");
const tools_1 = require("../../utils/tools");
const fs_extra_1 = require("fs-extra");
const parse_script_1 = require("./script/parse-script");
const style_1 = require("./style");
const css_1 = require("css");
function transformResource(input, output, ignoreList, dir) {
    const dirPath = path_1.join(input, dir || '.');
    fs_1.readdirSync(dirPath).forEach((file) => {
        const filePath = path_1.join(dirPath, file);
        const relativePath = tools_1.normalizePath(path_1.join(dir || '.', file));
        if (fs_1.statSync(filePath).isFile()) {
            if (!ignoreList.includes(filePath) && !['.wxml'].includes(path_1.extname(filePath))) {
                if (path_1.extname(filePath) === '.wxs') {
                    file = file.replace('.wxs', '.ux');
                }
                if (path_1.extname(filePath) === '.wxss') {
                    const outFile = file.replace('.wxss', '.css');
                    const styleRaw = fs_1.readFileSync(filePath, 'utf-8');
                    const styleCode = css_1.stringify(style_1.cssRewriter(styleRaw).ast);
                    if (styleCode) {
                        fs_extra_1.outputFileSync(path_1.join(output, dir || '.', outFile), styleCode);
                    }
                }
                else if (path_1.extname(file) === '.js') {
                    const scriptCode = parse_script_1.parseScript(fs_1.readFileSync(filePath, 'utf-8'));
                    if (scriptCode) {
                        fs_extra_1.outputFileSync(path_1.join(output, dir || '.', file), scriptCode);
                    }
                }
                else {
                    fs_extra_1.copySync(filePath, path_1.join(output, dir || '.', file));
                }
            }
        }
        else {
            transformResource(input, output, ignoreList, relativePath);
        }
    });
}
exports.transformResource = transformResource;
