"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function parseAppScriptPlugin(babel) {
    const { types: t } = babel;
    return {
        visitor: {
            Identifier(path) {
                if (path.node.name === 'App' && path.parentPath.container.type === 'ExpressionStatement') {
                    const page = t.exportDefaultDeclaration(path.container.arguments[0]);
                    path.parentPath.insertBefore(t.importDeclaration([t.importDefaultSpecifier(t.identifier('polyfill'))], t.stringLiteral('./polyfill/script/polyfill')));
                    page.declaration.properties.push(t.spreadElement(t.Identifier('polyfill')));
                    page.declaration.properties.unshift(t.Identifier('onCreate () { global.__proto__.$app = this; }'));
                    path.parentPath.insertAfter(page);
                    path.parentPath.remove();
                }
                if (path.node.name === 'onLaunch') {
                    path.node.name = 'onCreate';
                    if (t.isObjectMethod(path.parentPath)) {
                        path.container.body.body.push(t.Identifier('global.__proto__.$app = this;'));
                    }
                    if (t.isObjectProperty(path.parentPath)) {
                        path.container.value.body.body.push(t.Identifier('global.__proto__.$app = this;'));
                    }
                }
                if (path.node.name === 'currentTarget' || path.node.name === 'target') {
                    path.node.name = '_target.attr';
                }
                if (path.node.name === 'dataset') {
                    path.parentPath.replaceWith(path.parentPath.container.object.object);
                    const str = path.parentPath.container.property.name;
                    path.parentPath.container.property.name = 'data' + str[0].toUpperCase() + str.substring(1);
                }
                if (path.node.name === 'wx') {
                    path.node.name = `this`;
                }
                if (path.node.name === 'require') {
                    const callExpression = path.parentPath;
                    if (t.isCallExpression(callExpression) && callExpression.node.arguments && callExpression.node.arguments.length === 1) {
                        if (t.isStringLiteral(callExpression.node.arguments[0]) && callExpression.node.arguments[0].value.startsWith('/')) {
                            callExpression.node.arguments[0].value = '.' + callExpression.node.arguments[0].value;
                        }
                    }
                }
            },
        },
    };
}
exports.parseAppScriptPlugin = parseAppScriptPlugin;
