"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lifeCycles = {
    onLoad: 'onInit',
    onUnload: 'onDestroy',
};
function quickAppMiniProPlugin(babel) {
    const { types: t } = babel;
    return {
        visitor: {
            CallExpression(path) {
                if (path.node.callee.name === 'getApp') {
                    path.replaceWith(t.identifier('global.$app'));
                }
            },
            MemberExpression(path) {
                if (path.node.property.name === 'setData') {
                    const properties = path.container.arguments[0].properties;
                    if (!properties) {
                        path.parentPath.addComment('leading', 'todo plz change it yourself');
                        return;
                    }
                    properties.map(i => {
                        let prefix = 'this';
                        if (path.node.object.name) {
                            prefix = path.node.object.name;
                        }
                        let left;
                        if (t.isIdentifier(i.key)) {
                            left = t.identifier(prefix + '.' + i.key.name);
                        }
                        if (t.isStringLiteral(i.key)) {
                            left = t.identifier(prefix + '.' + i.key.value);
                        }
                        path.parentPath.insertAfter(t.expressionStatement(t.assignmentExpression('=', left, i.value)));
                    });
                    path.parentPath.remove();
                }
            },
            Identifier(path) {
                if ((path.node.name === 'Page' || path.node.name === 'Component') && path.parentPath.container.type === 'ExpressionStatement') {
                    if (path.parentPath.parentPath.listKey === 'body') {
                        const page = t.exportDefaultDeclaration(path.container.arguments[0]);
                        path.parentPath.insertAfter(page);
                        path.parentPath.remove();
                    }
                }
                if (Object.keys(lifeCycles).includes(path.node.name)) {
                    path.node.name = lifeCycles[path.node.name];
                }
                if (path.node.name === 'currentTarget' || path.node.name === 'target') {
                    if (t.isMemberExpression(path.parentPath)) {
                        path.node.name = '_target.attr';
                    }
                }
                if (path.node.name === 'dataset' && path.parentPath.container.object) {
                    path.parentPath.replaceWith(path.parentPath.container.object.object);
                    const str1 = path.parentPath.container.property.name;
                    const str2 = path.parentPath.container.property.value;
                    if (t.isIdentifier(path.parentPath.container.property)) {
                        path.parentPath.container.property.name = 'data' + str1[0].toUpperCase() + str1.substring(1);
                    }
                    if (t.isStringLiteral(path.parentPath.container.property)) {
                        path.parentPath.container.property.value = 'data' + str2[0].toUpperCase() + str2.substring(1);
                    }
                }
                if (path.node.name === 'wx') {
                    path.node.name = `qa`;
                }
                if (path.node.name === 'require') {
                    const callExpression = path.parentPath;
                    if (t.isCallExpression(callExpression) && callExpression.node.arguments && callExpression.node.arguments.length === 1) {
                        if (t.isStringLiteral(callExpression.node.arguments[0]) && callExpression.node.arguments[0].value.startsWith('/')) {
                            callExpression.node.arguments[0].value = '.' + callExpression.node.arguments[0].value;
                        }
                    }
                }
                if (path.node.name === 'data') {
                    const keys = ['self', 'that', '_this'];
                    const node = path.container.object;
                    if (t.isMemberExpression(path.parentPath)) {
                        if (t.isThisExpression(node)) {
                            path.parentPath.replaceWith(t.ThisExpression());
                        }
                        if (node.name && keys.includes(node.name)) {
                            path.parentPath.replaceWith(t.identifier(node.name));
                        }
                    }
                }
            },
        },
    };
}
exports.quickAppMiniProPlugin = quickAppMiniProPlugin;
