"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tools_1 = require("../../../utils/tools");
const tools_2 = require("./rules/tools");
const declaration_1 = require("./rules/declaration");
function processInlineDeclaration(declaration) {
    const ret = [];
    if (declaration.property.indexOf('-webkit-') === 0) {
        declaration.property = declaration.property.replace('-webkit-', '');
    }
    declaration.value = tools_2.processDeclarationValue(declaration.value);
    if (declaration_1.declarations.hasOwnProperty(declaration.property)) {
        let processDeclaration = declaration_1.declarations[declaration.property];
        if (typeof processDeclaration === 'function') {
            processDeclaration = processDeclaration(declaration.value, declaration, (property, value) => {
                ret.push(property + ':' + value);
            }, {
                declarations: [],
            });
        }
        if (Array.isArray(processDeclaration)) {
            processDeclaration.forEach(declaration => {
                ret.push(declaration.property + ':' + declaration.value);
            });
        }
        else if (typeof processDeclaration === 'object') {
            ret.push(processDeclaration.property + ':' + processDeclaration.value);
        }
        else if (typeof processDeclaration === 'string') {
            if (processDeclaration.indexOf('I:') === 0) {
                return ret;
            }
            else if (processDeclaration.indexOf('W:') === 0) {
                return ret;
            }
            else if (processDeclaration.indexOf('E:') === 0) {
                return ret;
            }
        }
        ret.push(declaration.property + ':' + declaration.value);
    }
    return ret;
}
function inlineStyleTransformer(code) {
    const matches = tools_1.getMatches(code, /([\w-]+)\s*:\s*([^;]+)/);
    if (matches.length) {
        let ret = [];
        matches.forEach(match => {
            if (match.length === 3) {
                if (!tools_1.isExpression(match[2])) {
                    ret = ret.concat(processInlineDeclaration({
                        property: match[1],
                        value: match[2],
                    }));
                }
                else {
                    ret.push(match[1] + ':' + match[2]);
                }
            }
        });
        return ret.join(';');
    }
    return code;
}
exports.inlineStyleTransformer = inlineStyleTransformer;
