"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tools_1 = require("../tools");
const text_1 = require("./text");
const transform_1 = require("./transform");
const transition_1 = require("./transition");
const animation_1 = require("./animation");
const background_1 = require("./background");
const border_1 = require("./border");
const box_1 = require("./box");
const component_1 = require("./component");
const dimension_1 = require("./dimension");
const flexbox_1 = require("./flexbox");
const font_1 = require("./font");
const margin_1 = require("./margin");
const padding_1 = require("./padding");
const position_1 = require("./position");
exports.declarations = Object.assign({}, text_1.text, transform_1.transform, transition_1.transition, animation_1.animation, background_1.background, border_1.border, box_1.box, component_1.component, dimension_1.dimension, flexbox_1.flexbox, font_1.font, margin_1.margin, padding_1.padding, position_1.position);
function declarationProcessor(declaration, rule, output) {
    if (!declaration.position) {
        declaration.position = {
            start: {
                line: 1,
                column: 1,
            },
            end: {
                line: 1,
                column: 1,
            },
        };
    }
    let property = declaration.property || '';
    if (property.indexOf('-webkit-') === 0) {
        declaration.property = property.replace('-webkit-', '');
        property = property.replace('-webkit-', '');
    }
    declaration.value = tools_1.processDeclarationValue(declaration.value);
    if (exports.declarations.hasOwnProperty(property)) {
        let processDeclaration = exports.declarations[property];
        if (typeof processDeclaration === 'function') {
            processDeclaration = processDeclaration(declaration.value, declaration, (property, value) => {
                output.declaration.inserted.push({
                    property,
                    value,
                });
            }, rule);
        }
        if (Array.isArray(processDeclaration)) {
            output.declaration.inserted.concat(processDeclaration);
        }
        else if (typeof processDeclaration === 'object') {
            output.declaration.inserted.push(processDeclaration);
        }
        else if (typeof processDeclaration === 'string') {
            if (processDeclaration.indexOf('I:') === 0) {
                output.declaration.deleted.push(declaration);
            }
            if (processDeclaration.indexOf('W:') === 0) {
                output.declaration.deleted.push(declaration);
            }
            if (processDeclaration.indexOf('E:') === 0) {
                output.declaration.deleted.push(declaration);
                const msg = 'E: 样式`' + declaration.property + ':' + declaration.value + '`不支持';
                output.logs.push({
                    reason: msg,
                    line: declaration.position.start.line,
                    column: declaration.position.start.column,
                });
            }
        }
    }
    else {
        output.declaration.deleted.push(declaration);
        output.logs.push({
            reason: 'E: 缺少`' + declaration.property + '`转换器',
            line: declaration.position.start.line,
            column: declaration.position.start.column,
        });
    }
}
exports.declarationProcessor = declarationProcessor;
