"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const css_1 = require("css");
const declaration_1 = require("./declaration");
const selector_1 = require("./selector");
const tools_1 = require("../../../../utils/tools");
const tools_2 = require("./tools");
function transformRule(rule, output) {
    output.declaration = {
        deleted: [],
        inserted: [],
    };
    const declarations = rule.declarations || [];
    const selectors = rule.selectors
        .map((selector) => selector_1.selectorRewriter(selector, rule, output))
        .filter(v => !!v);
    if (!selectors.length) {
        let commentCssCode = '';
        try {
            commentCssCode = css_1.stringify({
                stylesheet: {
                    rules: [rule],
                },
            });
        }
        catch (e) {
            output.logs.push({
                reason: 'E:wxss转换失败',
                line: rule.position.start.line,
                column: rule.position.start.column,
            });
        }
        return {
            type: 'comment',
            comment: `${tools_1.comment('unsupported selector')}\n${commentCssCode}`,
        };
    }
    rule.selectors = selectors;
    declarations.forEach((declaration) => {
        if (declaration.type === 'declaration') {
            declaration_1.declarationProcessor(declaration, rule, output);
        }
    });
    output.declaration.deleted.forEach((declaration) => tools_2.removeDeclaration(declaration, rule));
    output.declaration.inserted.forEach((declaration) => tools_2.addDeclaration(declaration.property, declaration.value, rule));
    output.declaration.deleted.forEach((declaration) => tools_2.addComment(declaration.property, declaration.value, rule));
    return rule;
}
exports.transformRule = transformRule;
