"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cssWhat = require("css-what");
const simpleSelectorRegex = /^[.#]?[A-Za-z0-9_\-:]+$/;
const compoundSelectorRegex = /^([.#]?[A-Za-z0-9_-]+(\s+|\s*>\s*))+([.#]?[A-Za-z0-9_\-:]+)$/;
function selectorRewriter(selector, rule, output) {
    if (!(simpleSelectorRegex.test(selector) || compoundSelectorRegex.test(selector))) {
        output.logs.push({
            reason: 'W:选择器`' + selector + '`不支持',
            line: rule.position.start.line,
            column: rule.position.start.column,
        });
        return false;
    }
    if (selector.includes(':before') ||
        selector.includes(':after') ||
        selector.includes(':last-child') ||
        selector.includes(':first-child')) {
        output.logs.push({
            reason: 'W:暂未支持的伪类选择器：' + selector,
            line: rule.position.start.line,
            column: rule.position.start.column,
        });
        return false;
    }
    selector = cssWhat(selector)[0]
        .map((subselect) => {
        if (subselect.type === 'tag') {
            return '.qa-' + subselect.name;
        }
        else if (subselect.type === 'descendant') {
            return ' ';
        }
        else if (subselect.type === 'attribute') {
            if (subselect.name === 'class') {
                return '.' + subselect.value;
            }
            else if (subselect.name === 'id') {
                return '#' + subselect.value;
            }
        }
        return '';
    })
        .join('');
    return selector;
}
exports.selectorRewriter = selectorRewriter;
