"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tools_1 = require("../../../../utils/tools");
const defaultFontSize = 32;
function processDeclarationValueUnit(value) {
    value = value.replace('!important', '');
    const lowerCaseV = value.toLowerCase();
    if (lowerCaseV.includes('rpx')) {
        return lowerCaseV.replace('rpx', 'px');
    }
    else if (lowerCaseV.includes('px')) {
        const numberV = parseFloat(lowerCaseV);
        if (!isNaN(numberV)) {
            return numberV * 2 + 'px';
        }
    }
    else if (lowerCaseV.includes('em')) {
        const numberV = parseFloat(lowerCaseV);
        if (!isNaN(numberV)) {
            return numberV * defaultFontSize + 'px';
        }
    }
    else if (lowerCaseV.includes('vh')) {
        return '100%';
    }
    return value;
}
function processDeclarationValue(value) {
    if (typeof value === 'string') {
        return value
            .split(/\s+/)
            .map(v => processDeclarationValueUnit(v))
            .join(' ');
    }
    return value;
}
exports.processDeclarationValue = processDeclarationValue;
function getDeclarationValue(property, rule) {
    const declarations = rule.declarations.filter((declaration) => declaration.property === property);
    return (declarations.length && declarations[0]) || false;
}
exports.getDeclarationValue = getDeclarationValue;
function removeDeclaration(declaration, rule) {
    rule.declarations.splice(rule.declarations.findIndex((v) => v.property === declaration.property && v.value === declaration.value), 1);
}
exports.removeDeclaration = removeDeclaration;
function addDeclaration(property, value, rule) {
    rule.declarations.push({
        type: 'declaration',
        property,
        value,
    });
}
exports.addDeclaration = addDeclaration;
function addComment(property, value, rule) {
    rule.declarations.push({
        type: 'comment',
        comment: `${property}:${value}; ${tools_1.comment('unsupported style')}`,
    });
}
exports.addComment = addComment;
