"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function assemble(nodes) {
    if (!Array.isArray(nodes)) {
        nodes = [nodes];
    }
    return nodes.map(node => walkNode(node)).join('\n');
}
exports.assemble = assemble;
function wrapNodeWithComment(nodeName) {
    return `<!-- ${nodeName} -->`;
}
function walkNode(node) {
    const attrs = Object.keys(node.attributes)
        .map(key => {
        if (key === 'else') {
            return `${key}`;
        }
        return `${key}="${node.attributes[key]}"`;
    })
        .join(' ');
    let nodeContent = node.content || '';
    let nodeStart = `<${node.name} ${attrs}>`;
    let nodeEnd = `</${node.name}>`;
    if (node.needComment) {
        nodeContent = '';
        nodeStart = wrapNodeWithComment(nodeStart);
        nodeEnd = wrapNodeWithComment(nodeEnd);
    }
    return `${nodeStart}${nodeContent} ${node.children
        .map(childNode => walkNode(childNode))
        .join(' ')} ${nodeEnd}`;
}
