"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const directives_1 = require("./directives/directives");
const events_1 = require("./events/events");
const handle_imports_1 = require("./imports/handle-imports");
const inline_style_transformer_1 = require("../style/inline-style-transformer");
const content_handle_1 = require("./util/content-handle");
const index_1 = require("./components/index");
exports.walkTemplate = (node, wxmlElement, options) => {
    const componentTransformer = index_1.default[node.name];
    if (!!componentTransformer) {
        componentTransformer(node, options);
    }
    if (node.name === 'template' && node.attributes.is) {
        handle_imports_1.handleTemplate(node);
    }
    Object.keys(node.attributes).forEach((name) => {
        if (name.includes('wx:')) {
            directives_1.handleDirective(node, name);
        }
        else if (events_1.events.hasOwnProperty(name)) {
            events_1.handleEvent(node, name);
        }
        else if (name === 'style') {
            const styles = node.attributes.style;
            node.attributes.style = inline_style_transformer_1.inlineStyleTransformer(styles);
        }
    });
    if (node.children) {
        node.children = node.children.filter(childNode => {
            if (childNode.name === 'import') {
                wxmlElement.imports.push(childNode);
                return false;
            }
            if (childNode.name === 'template' && childNode.attributes.name) {
                wxmlElement.templates.push(childNode);
                return false;
            }
            return true;
        });
        node.children.forEach((childNode, index) => {
            exports.walkTemplate(childNode, wxmlElement, options);
        });
    }
    content_handle_1.fixContent(node);
    return node;
};
