"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assemble_1 = require("../assemble");
const parse_wxml_file_1 = require("../parse-wxml-file");
const path = require("path");
const fs_1 = require("fs");
const tools_1 = require("../../../../utils/tools");
const fs_extra_1 = require("fs-extra");
const handle_template_1 = require("../handle-template");
const log_1 = require("../../../../utils/log");
function handleTemplate(templateNode) {
    templateNode.name = patchCompName(templateNode.attributes['is']);
    delete templateNode.attributes['is'];
    wrapDataNode(templateNode);
}
exports.handleTemplate = handleTemplate;
function wrapDataNode(node) {
    const dataNode = node.attributes['data'];
    if (dataNode && dataNode.startsWith('{{')) {
        const innerData = dataNode.trim().substring(2, dataNode.trim().length - 2);
        if (innerData.startsWith('...')) {
            node.attributes['data'] = `{{ ${innerData.substring(3)} }}`;
        }
        else {
            node.attributes['data'] = `{{ {${innerData}} }}`;
        }
    }
}
exports.wrapDataNode = wrapDataNode;
function parseImportFiles(importNodes, wxmlPath, options) {
    if (!wxmlPath) {
        console.log('no wxmlPath, ignore generate import file');
        return '';
    }
    let deps = '';
    importNodes.forEach(i => {
        const srcPath = i.attributes['src'];
        let basePath = path.dirname(wxmlPath);
        if (srcPath.startsWith('/')) {
            basePath = options.input;
        }
        let importFilePath = path.join(basePath, srcPath);
        if (!importFilePath.endsWith('.wxml')) {
            importFilePath = importFilePath + '.wxml';
        }
        if (!fs_1.existsSync(importFilePath)) {
            log_1.logOutput.push(`wxml: ${wxmlPath} can't find component ${importFilePath}`);
            return;
        }
        let wxml = fs_1.readFileSync(importFilePath, 'utf-8');
        wxml = `<root>${wxml}</root>`;
        let root = parse_wxml_file_1.parseWxml(wxml);
        const children = root.children;
        children.forEach(child => {
            if (child.name !== 'template') {
                return;
            }
            const componentName = child.attributes['name'];
            delete child.attributes['name'];
            const rP = tools_1.relativePath(options.input, importFilePath);
            const outputNewName = path.join(path.dirname(rP), `${componentName}.ux`);
            const outputFile = path.join(options.output, outputNewName);
            const src = path.dirname(tools_1.relativePath(path.dirname(wxmlPath), importFilePath)) + '/' + componentName + '.ux';
            const baseOutput = path.dirname(tools_1.relativePath(outputFile, options.output));
            deps = `${deps}\n<import name="${patchCompName(componentName)}" src="${src}"></import>`;
            fs_extra_1.ensureDirSync(path.dirname(outputFile));
            if (!fs_1.existsSync(outputFile)) {
                const wxmlElements = {
                    wxs: [],
                    templates: [],
                    imports: [],
                };
                const c = handle_template_1.walkTemplate(child, wxmlElements, options);
                const newTemplate = assemble_1.assemble(c);
                let imports = '';
                if (wxmlElements.imports.length > 0) {
                    imports = parseImportFiles(wxmlElements.imports, wxmlPath, options);
                    imports = imports.trim() + '\n';
                }
                const compTemplate = imports + require('pretty-data').pd.xml(newTemplate);
                const cssPaths = [`@import '${baseOutput}/app.css';`];
                cssPaths.push(`@import '${baseOutput}/polyfill/stylesheet/polyfill.css';`);
                const stylePart = `\n<style>\n${cssPaths.join('\n')}\n</style>`;
                const content = compTemplate + stylePart + compScript;
                fs_1.writeFileSync(outputFile, content);
            }
        });
    });
    return deps;
}
exports.parseImportFiles = parseImportFiles;
const compScript = `
<script>
export default {
    props: ['data'],
    onInit() {
      this.setPropsData(this.data)
      this.$watch('data','handlePropsData')
    },
    setPropsData(data) {
      data && Object.keys(data).forEach(key => this.$set(key, data[key]))
    },
    handlePropsData(newVal, oldVal) {
      this.setPropsData(newVal)
    }
}
</script>
`;
function patchCompName(name) {
    if (name === 'head') {
        name = 'header';
    }
    return name;
}
exports.patchCompName = patchCompName;
