"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const sax = require("sax");
const assemble_1 = require("./assemble");
const handle_template_1 = require("./handle-template");
const handle_imports_1 = require("./imports/handle-imports");
const tab_bars_1 = require("./tab-bars/tab-bars");
const handle_comps_1 = require("./comps/handle-comps");
function parseWxmlFile(wxmlPath, options) {
    const template = fs_1.readFileSync(wxmlPath, 'utf-8');
    return parseTemplate(template, wxmlPath, options);
}
exports.parseWxmlFile = parseWxmlFile;
function parseTemplate(wxml, wxmlPath, options) {
    wxml = `<div class="qa-view">${wxml}</div>`;
    let root = parseWxml(wxml);
    const wxmlElements = {
        wxs: [],
        templates: [],
        imports: [],
        comps: [],
    };
    root = handle_template_1.walkTemplate(root, wxmlElements, options);
    let tabBar = '';
    if (options && options.tabBar) {
        const paths = options.tabBar.list.map(i => i.pagePath);
        if (paths.includes(options.pagePath)) {
            tabBar = tab_bars_1.generateTabbar(options);
        }
    }
    let newTemplate = assemble_1.assemble(root);
    if (tabBar === '') {
        newTemplate = `<template>
      ${newTemplate}
    </template>`;
    }
    else {
        newTemplate = `<template>
      <div class="qa-view qa-tabbar-page">
        ${newTemplate}
        ${tabBar}
      </div>
    </template>`;
    }
    let imports = '';
    if (options && options.pageJson && options.pageJson.usingComponents) {
        for (let [key, value] of Object.entries(options.pageJson.usingComponents)) {
            wxmlElements.comps.push({ name: key, path: value });
        }
        imports = imports + '\n' + handle_comps_1.parseCompsFiles(wxmlElements.comps, wxmlPath, options);
    }
    if (wxmlElements.imports.length > 0) {
        imports = imports + '\n' + handle_imports_1.parseImportFiles(wxmlElements.imports, wxmlPath, options);
    }
    imports = imports.trim();
    if (imports) {
        imports = imports + '\n';
    }
    return imports + require('pretty-data').pd.xml(newTemplate);
}
exports.parseTemplate = parseTemplate;
function parseWxml(wxml) {
    const parser = sax.parser(false, {
        trim: true,
        lowercase: true,
        position: true,
    });
    let root;
    let currentParent;
    let stack = [];
    parser.onerror = e => {
        console.log(e);
    };
    parser.ontext = t => {
        currentParent && (currentParent.content = t.trim() || '');
    };
    parser.onopentag = function (node) {
        node.processed = false;
        node.children = [];
        node.location = {
            line: this.line,
            column: this.column,
        };
        if (!root) {
            root = node;
        }
        if (currentParent) {
            node.parent = currentParent;
            currentParent.children.push(node);
        }
        currentParent = node;
        stack.push(currentParent);
    };
    parser.onclosetag = tagName => {
        if (stack.length > 0) {
            stack.length = stack.length - 1;
            currentParent = stack[stack.length - 1];
        }
    };
    parser.write(wxml).close();
    return root;
}
exports.parseWxml = parseWxml;
