/**
 * https://doc.quickapp.cn/features/system/device.html
 * @param params
 */
export function getSystemInfo(params) {
  require('@system.device').getInfo({
    success: function(data) {
      if (params.success) {
        data['pixelRatio'] = 'unsupported';
        data['windowWidth'] = data.screenWidth; // 快应用没有可使用窗口宽度，暂时用屏幕宽度代替
        data['windowHeight'] = data.screenHeight; // 同上
        data['statusBarHeight'] = 'unsupported';
        data['fontSizeSetting'] = 'unsupported';
        data['SDKVersion'] = 'unsupported';
        data['benchmarkLevel'] = 'unsupported';
        data['version'] = data.platformVersionCode;// 没有微信版本号,使用平台版本号代替
        params.success(data);
      }
    },
    fail: function() {
      params.fail && params.fail();
    },
    complete: function() {
      params.complete && params.complete();
    },
  });
}

/**
 * 目前暂不支持同步接口，如需实现同步效果可自行采取async/await方式实现
 * https://doc.quickapp.cn/tutorial/framework/using-async.html
 */
export async function getSystemInfoSync() {
  return new Promise((resolve, reject) => {
    require('@system.device').getInfo({
      success: function(data) {
        if (params.success) {
          data['pixelRatio'] = 'unsupported';
          data['windowWidth'] = data.screenWidth; // 快应用没有可使用窗口宽度，暂时用屏幕宽度代替
          data['windowHeight'] = data.screenHeight; // 同上
          data['statusBarHeight'] = 'unsupported';
          data['fontSizeSetting'] = 'unsupported';
          data['SDKVersion'] = 'unsupported';
          data['benchmarkLevel'] = 'unsupported';
          data['version'] = data.platformVersionCode;// 没有微信版本号,使用平台版本号代替
          resolve(data);
        }
      },
      fail: function(err) {
        reject(err);
      },
      complete: function(msg) {
        resolve(msg);
      },
    });
  });
}
