import * as actionSheet from './ui/action-sheet';
import * as modal from './ui/modal';
import * as toast from './ui/toast';
import * as navigation from './ui/navigation';
import * as navigator from './ui/navigator';
import { fixPage } from './ui/navigator';
import * as image from './media/image';
import * as video from './media/video';
import * as voice from './media/voice';
import * as request from './network/request';
import * as location from './location';
import * as backgroundAudio from './media/background-audio';
import * as system from './device/system-info';
import * as networkType from './device/get-network-type';
import * as refresh from './ui/pull-down-refresh';
import * as animation from './ui/animation';
import * as canvas from './ui/canvas';
import * as data from './data/data';
import * as open from './open/open';
import * as upload from './network/upload';
import * as download from './network/download';
import * as loading from './ui/loading';
import * as makePhoneCall from './device/makePhoneCall';
import * as sensor from './device/sensor';
import * as barcode from './device/barcode';

const qa = {
  ...actionSheet,
  ...modal,
  ...toast,
  ...navigation,
  ...navigator,
  ...image,
  ...video,
  ...voice,
  ...backgroundAudio,
  ...location,
  ...request,
  ...system,
  ...refresh,
  ...animation,
  ...canvas,
  ...data,
  ...open,
  ...upload,
  ...download,
  ...loading,
  ...networkType,
  ...makePhoneCall,
  ...sensor,
  ...barcode,
};

const handler = {
  get(target, name) {
    if (name in target) {
      return Reflect.get(target, name);
    }
    return function() {
      console.log(`${name} current not support in quickapp`);
    };
  },
};
const qaProxy = new Proxy(qa, handler);

const injectRef = Object.getPrototypeOf(global) || global;
injectRef.qa = qaProxy;

export default {
  pushPage: function(page) {
    require('@system.router').push({ uri: fixPage(page) });
  },
  switchTab: function(url) {
    if(url === require('@system.router').getState().name){
      return;
    }
    require('@system.router').replace({ uri: url });
  },
  ...qa,
};
